pub enum StridedError {
RankMismatch(usize, usize),
ShapeMismatch(Vec<usize>, Vec<usize>),
InvalidAxis {
axis: usize,
rank: usize,
},
StrideLengthMismatch,
OffsetOverflow,
ScalarConversion,
NonSquare {
rows: usize,
cols: usize,
},
}Expand description
Errors that can occur during strided array operations.
Variants
RankMismatch(usize, usize)
Array ranks do not match.
ShapeMismatch(Vec<usize>, Vec<usize>)
Array shapes are incompatible for the operation.
InvalidAxis
Invalid axis index for the given array rank.
StrideLengthMismatch
Stride array length doesn’t match dimensions.
OffsetOverflow
Integer overflow while computing array offset.
ScalarConversion
Failed to convert a scalar value for scaling operation.
NonSquare
Matrix is not square when a square matrix was required.